@ECHO OFF && SETLOCAL
::
:: Adobe Photoshop CC 2017, version 18.0
::

::
:: Log file
::
SET LogFile=Photoshop_install.log

::
:: Initialize log file
::
ECHO P4GT plug-in installation
ECHO P4GT plug-in installation > %LogFile%
date /T >> %LogFile%
time /T >> %LogFile%

::
:: Product Settings
::
SET Product=Adobe Photoshop CC 2017

REM ==============Determine the distribution file name we are going to install===============

::
:: English Photoshop CC 2017 plug-in
::
SET DistFile=P4GT-Photoshop-2017_x64.8li
IF NOT EXIST "%DistFile%" GOTO :DISTFILE_NEXT1
GOTO :DISTFILE_VALID

:DISTFILE_NEXT1
::
:: Japanese Photoshop CC 2017 plug-in
::
SET DistFile=P4GT-Photoshop-2017_x64_ja.8li
IF NOT EXIST "%DistFile%" GOTO :DISTFILE_NEXT2
GOTO :DISTFILE_VALID

:DISTFILE_NEXT2
::
:: Room for more dist file choices
::
REM GOTO :DISTFILE_VALID

::
:: Report error that no file was found for installation
::
ECHO %Product% plug-in file %DistFile% not in current directory
ECHO %Product% plug-in file %DistFile% not in current directory >> %LogFile%
GOTO :INSTALL_FAILED

REM ==============Determine the plug-in install location=====================================

:DISTFILE_VALID

::
:: Read the registry for the plug-in install location
::
SET RegLoc=HKLM\SOFTWARE\Adobe\Photoshop\110.0
SET RegKey=PluginPath
SET PluginSubDir=Automate
@for /F "tokens=1,2*" %%i in ('reg query "%RegLoc%" /v "%RegKey%"') DO (
	@if "%%i"=="%RegKey%" (
		@SET PluginDir=%%k
	)
)
@SET PluginInstDir=%PluginDir%%PluginSubDir%

REM ==============Product plug-in directory should already exist=============================

IF EXIST "%PluginInstDir%" GOTO :RENAME_EXISTING
ECHO %Product% plug-in directory %PluginInstDir% does not exist
ECHO %Product% plug-in directory %PluginInstDir% does not exist >> %LogFile%
GOTO :INSTALL_FAILED

REM ==============Rename existing plug-in file===============================================

:RENAME_EXISTING

@SET PluginFile=%PluginInstDir%\%DistFile%

IF NOT EXIST "%PluginFile%" GOTO :INSTALL_PLUGIN
ECHO Move existing %Product% plug-in %PluginFile% into %TEMP%
ECHO Move existing %Product% plug-in %PluginFile% into %TEMP% >> %LogFile%

move /Y "%PluginFile%" "%TEMP%\%DistFile%" >> %LogFile% 2>>&1

::
:: Did the move fail?
::
IF NOT EXIST "%PluginFile%" GOTO :INSTALL_PLUGIN
ECHO Failed to save the existing plug-in file %TargetFile% into %TEMP%
ECHO You may need Administrator privileges to run this script
ECHO Failed to save the existing plug-in file %TargetFile% into %TEMP% >> %LogFile%
ECHO You may need Administrator privileges to run this script >> %LogFile%
GOTO :INSTALL_FAILED

REM ===================Installing the plug-in file===========================================

:INSTALL_PLUGIN

ECHO Copy %DistFile% to plug-in directory
ECHO Copy %DistFile% to plug-in directory >> %LogFile%

copy /B /Y "%DistFile%" "%PluginFile%" >> %LogFile% 2>>&1

IF EXIST "%PluginFile%" GOTO :MKDIR_DISTDIR
ECHO Failed to copy %DistFile% to plug-in directory
ECHO Failed to copy %DistFile% to plug-in directory >> %LogFile%
GOTO :INSTALL_FAILED

REM ===================Create the Perforce Install Directory=================================

:MKDIR_DISTDIR

SET PerforceTarget=%ProgramFiles(x86)%\Perforce\P4GT
IF EXIST "%PerforceTarget%" GOTO :COPY_HELPFILE

ECHO Create Perforce install directory
ECHO Create Perforce install directory >> %LogFile%

mkdir "%PerforceTarget%" >> %LogFile% 2>>&1

IF EXIST "%PerforceTarget%" GOTO :COPY_HELPFILE
ECHO Failed to create %PerforceTarget% directory
ECHO Failed to create %PerforceTarget% directory >> %LogFile%
GOTO :INSTALL_FAILED

REM ===================Installing the P4GT help file=========================================

:COPY_HELPFILE

SET P4GT_CHM=p4gt.chm
SET P4GT_CHMDist=%PerforceTarget%\%P4GT_CHM%
IF NOT EXIST "%P4GT_CHM%" GOTO :COPY_RELNOTES

ECHO Copy P4GT help file to Perforce install directory
ECHO Copy P4GT help file to Perforce Install directory >> %LogFile%

copy /B /Y "%P4GT_CHM%" "%P4GT_CHMDist%" >> %LogFile% 2>>&1

IF EXIST "%P4GT_CHMDist%" GOTO :REGISTER_HELP
ECHO Failed to copy P4GT help file
ECHO Failed to copy P4GT help file >> %LogFile%
GOTO :COPY_RELNOTES

REM ===================Register the P4GT help file===========================================

:REGISTER_HELP

SET RegHelpKey=HKEY_LOCAL_MACHINE\Software\Perforce\P4GT

ECHO Register P4GT help file
ECHO Register P4GT help file >> %LogFile%

reg add "%RegHelpKey%" /V "HelpFilePath" /D "%P4GT_CHMDist%" /F >> %LogFile% 2>>&1

IF %ERRORLEVEL% EQU 0 GOTO :COPY_RELNOTES
ECHO Failed to register P4GT help file
ECHO Failed to register P4GT help file >> %LogFile%

REM ===================Installing the P4GT release notes file================================

:COPY_RELNOTES

SET P4GT_Relnotes=p4gtpsnotes.txt
SET P4GT_RelnotesDist=%PerforceTarget%\%P4GT_Relnotes%
IF NOT EXIST "%P4GT_Relnotes%" GOTO :FINISH_MSG

ECHO Copy P4GT release notes to Perforce install directory
ECHO Copy P4GT release notes to Perforce Install directory >> %LogFile%

copy /B /Y "%P4GT_Relnotes%" "%P4GT_RelnotesDist%" >> %LogFile% 2>>&1

IF EXIST "%P4GT_RelnotesDist%" GOTO :FINISH_MSG
ECHO Failed to copy P4GT release notes
ECHO Failed to copy P4GT release notes >> %LogFile%

:FINISH_MSG

ECHO P4GT plug-in install finished for %Product%
ECHO P4GT plug-in install finished for %Product% >> %LogFile%

::
:: batch script oddities
::
GOTO :INSTALL_GOOD

::
:: Emit install failure message
::
:INSTALL_FAILED
ECHO Installation failed, see the logfile %LogFile%
ECHO Installation failed, see the logfile %LogFile% >> %LogFile%
GOTO :END


::
:: Emit install success message
::
:INSTALL_GOOD
ECHO Installation Successful
ECHO Installation Successful >> %LogFile%

:END

